﻿Public Class USBIO

    Enum IO2 As Byte
        inOut = &H20
        outIn = &H21
        RomRead = &HF0
        RomWrite = &HF1
        setSys = &HF8
        getSys = &HF9
    End Enum

    Enum FSIO As Byte
        inOut = &H20
        outIn = &H21
        repOut = &H22
        PwmPeriod = &H40
        PwmDuty = &H41
        PwmOnOff = &H42
        RomRead = &HF0
        RomWrite = &HF1
        setSys = &HF8
        getSys = &HF9
    End Enum

    Enum EMAX As Integer
        cmd = 64
        out = 8
        inp = 8
        Sys = 16
    End Enum

    Enum PORT As Byte
        P1 = 1
        P2 = 2
        P3 = 3
        P4 = 4

    End Enum

    '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    'VBA用の専用DLL（vbausbio.dll）用定義部
    '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
    '使用方法
    ' uio_findでUSB-IOを検索・初期化して，その後に
    ' uio_inp/outで読み書きしてください．
    ' uio_seldevで複数のUSB-IOを切り替えて使うことが出来ます．
    ' (uio_findを実行しなくても初めてuio_inp/outを実行するときには自動的に
    ' uio_findが呼ばれます．ただし，最初だけなのでUSB-IOが一度外されて，
    ' もう一度挿された場合などは無視されます．)
    '++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

    '------------------------------------------------------------------------------
    'USB-IOにPortを指定してデータを出力する
    'p3に1を指定すると，ポート1のp1にパルスを送りポート0を書き換えます
    '   Port    : Portを指定する（0,1）、パルス出力の場合はビット（0～3）
    '   OutDat  : データ（0～255）
    '   p3      : パルス出力有無（0:なし、1:あり）
    '   戻り値  : 0:正常、1:異常
    '------------------------------------------------------------------------------
    Declare Function uio_out Lib "vbausbio.dll" (ByVal Port As Integer, _
     ByVal OutDat As Integer, ByVal p3 As Integer) As Integer

    '------------------------------------------------------------------------------
    'USB-IOからPortを指定してデータを取得する
    'p3に1を指定すると，ポート1のp1にパルスを送りポート0から読み込みます
    '   InpDat  : 取得データ（取得したい変数を指定する）
    '   Port    : Portを指定する（0,1）、パルス出力の場合はビット（0～3）
    '   p3      : パルス出力有無（0:なし、1:あり）
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio_inp Lib "vbausbio.dll" (ByRef InpDat As Byte, _
     ByVal Port As Integer, ByVal p3 As Integer) As Integer

    '------------------------------------------------------------------------------
    'USB-IOを検索・初期化する
    '   戻り値  : 0:正常、1:必要なドライバが無い、2:USB-IOが繋がってない
    '------------------------------------------------------------------------------
    Declare Function uio_find Lib "vbausbio.dll" () As Integer

    '------------------------------------------------------------------------------
    'USB-IO用の資源を解放する
    '   戻り値  : 0
    '------------------------------------------------------------------------------
    Declare Function uio_free Lib "vbausbio.dll" () As Integer

    '------------------------------------------------------------------------------
    '繋がれているUSB-IOの数が戻り値に帰ります
    '   戻り値  : 個数
    '------------------------------------------------------------------------------
    Declare Function uio_getDevs Lib "vbausbio.dll" () As Integer

    '------------------------------------------------------------------------------
    'USB-IOを番号で指定する
    '   p1      : 番号(0～uio_getdevsで得た個数-1)　ただし０から
    '   戻り値  : 0
    '------------------------------------------------------------------------------
    Declare Function uio_selDev Lib "vbausbio.dll" (ByVal p1 As Integer) As Integer

    '------------------------------------------------------------------------------
    '番号を指定してVenderIDを取得する
    '   p1      : 番号(0～uio_getdevsで得た個数-1)　ただし０から
    '   戻り値  : VenderID
    '------------------------------------------------------------------------------
    Declare Function uio_getVid Lib "vbausbio.dll" (ByVal p1 As Integer) As Integer

    '------------------------------------------------------------------------------
    '番号を指定してProductIDを取得する
    '   p1      : 番号(0～uio_getdevsで得た個数-1)　ただし０から
    '   戻り値  : ProductID
    '------------------------------------------------------------------------------
    Declare Function uio_getPid Lib "vbausbio.dll" (ByVal p1 As Integer) As Integer

    '------------------------------------------------------------------------------
    'USB-IOにコマンドデータをセットし、USB-IOからデータを取得する
    '   Dat(0)  : 常に０
    '   Dat(1)  : コマンド
    '   Dat(2)  : 以降データ
    '   Dat(3)  : 　　：
    '　　：
    '   Dat(64)
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio_cmd Lib "vbausbio.dll" (ByRef Dat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IO2.0にPortを指定してデータを出力する
    '   OutDat(0): Portを指定する（1～2）
    '   OutDat(1): データ（0～255）
    '   OutDat(2): Portを指定する（1～2）
    '   OutDat(3): データ（0～255）
    '      :
    '   OutDat(7)
    '   戻り値  : 0:正常、1:異常
    '------------------------------------------------------------------------------
    Declare Function uio2_out Lib "vbausbio.dll" _
       (ByRef OutDat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IO2.0からデータを取得する
    '   inDat(0): 取得データ（Port1）
    '   inDat(1): 取得データ（Port2）
    '      :
    '   inDat(7): 取得データ（Port8）予備
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio2_inp Lib "vbausbio.dll" _
         (ByRef inDat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IO2.0にデータをセットし、USB-IOからデータを取得する
    '   Dat(0)  : Portを指定する（1～2）
    '   Dat(1)  : データ（0～255）
    '   Dat(2)  : Portを指定する（1～2）
    '   Dat(3)  : データ（0～255）
    '　　：
    '   Dat(7) :
    '
    '   Dat(0)  : 取得データ（Port1）
    '   Dat(1)  : 取得データ（Port2）
    '    ：
    '   Dat(7) :
    '
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio2_inOut Lib "vbausbio.dll" (ByRef Dat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IO2.0にデータをセットし、USB-IOからデータを取得する
    '   Dat(0)  : Portを指定する（1～2）
    '   Dat(1)  : データ（0～255）
    '   Dat(2)  : Portを指定する（1～2）
    '   Dat(3)  : データ（0～255）
    '　　：
    '   Dat(7) :
    '
    '   Dat(0)  : 取得データ（Port1）
    '   Dat(1)  : 取得データ（Port2）
    '    ：
    '   Dat(7) :
    '
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio2_outIn Lib "vbausbio.dll" (ByRef Dat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IOにシステム設定データを設定する。
    '   Dat(0)  : 
    '   Dat(1)  : 
    '　　：
    '   Dat(15) :
    '
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio2_setSys Lib "vbausbio.dll" (ByRef Dat As Byte) As Integer

    '------------------------------------------------------------------------------
    'USB-IOからシステム設定データを取得する。
    '   Dat(0)  : 
    '   Dat(1)  : 
    '　　：
    '   Dat(15) :
    '
    '   戻り値  : 0:正常、1:命令が書けなかった、2:データを取得できなかった
    '------------------------------------------------------------------------------
    Declare Function uio2_getSys Lib "vbausbio.dll" (ByRef Dat As Byte) As Integer


End Class

